@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from keystoneauth1 import loading as ks_loading
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_middleware import cors
@@ -26,17 +27,17 @@ paste_deploy_opts = [
 ]
 
 bind_opts = [
-    cfg.StrOpt('bind-host', default='0.0.0.0',
-               help='Address to bind the Murano API server to.'),
+    cfg.HostAddressOpt('bind-host', default='0.0.0.0',
+                       help='Address to bind the Murano API server to.'),
     cfg.PortOpt('bind-port',
                 default=8082,
                 help='Port the bind the Murano API server to.'),
 ]
 
 rabbit_opts = [
-    cfg.StrOpt('host', default='localhost',
-               help='The RabbitMQ broker address which used for communication '
-               'with Murano guest agents.'),
+    cfg.HostAddressOpt('host', default='localhost',
+                       help='The RabbitMQ broker address which used for '
+                            'communication with Murano guest agents.'),
 
     cfg.PortOpt('port',
                 default=5672,
@@ -55,6 +56,13 @@ rabbit_opts = [
                 help='Boolean flag to enable SSL communication through the '
                 'RabbitMQ broker between murano-engine and guest agents.'),
 
+    cfg.StrOpt('ssl_version',
+               default='',
+               help='SSL version to use (valid only if SSL enabled). '
+                    'Valid values are TLSv1 and SSLv23. SSLv2, SSLv3, '
+                    'TLSv1_1, and TLSv1_2 may be available on some '
+                    'distributions.'),
+
     cfg.StrOpt('ca_certs', default='',
                help='SSL cert file (valid only if SSL enabled).'),
 
@@ -66,21 +74,6 @@ rabbit_opts = [
 heat_opts = [
     cfg.StrOpt('url', help='Optional heat endpoint override'),
 
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                '"insecure" SSL connections and transfers with Heat API.'),
-
-    cfg.StrOpt('ca_file',
-               help='(SSL) Tells Murano to use the specified certificate file '
-               'to verify the peer running Heat API.'),
-
-    cfg.StrOpt('cert_file',
-               help='(SSL) Tells Murano to use the specified client '
-               'certificate file when communicating with Heat.'),
-
-    cfg.StrOpt('key_file', help='(SSL/SSH) Private key file name to '
-                                'communicate with Heat API.'),
-
     cfg.StrOpt('endpoint_type', default='publicURL',
                help='Heat endpoint type.'),
 
@@ -96,28 +89,12 @@ mistral_opts = [
                help='Mistral endpoint type.'),
 
     cfg.StrOpt('service_type', default='workflowv2',
-               help='Mistral service type.'),
-
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                '"insecure" SSL connections and transfers with Mistral.'),
-
-    cfg.StrOpt('ca_cert',
-               help='(SSL) Tells Murano to use the specified client '
-               'certificate file when communicating with Mistral.')
+               help='Mistral service type.')
 ]
 
 neutron_opts = [
     cfg.StrOpt('url', help='Optional neutron endpoint override'),
 
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                '"insecure" SSL connections and transfers with Neutron API.'),
-
-    cfg.StrOpt('ca_cert',
-               help='(SSL) Tells Murano to use the specified client '
-               'certificate file when communicating with Neutron.'),
-
     cfg.StrOpt('endpoint_type', default='publicURL',
                help='Neutron endpoint type.')
 ]
@@ -126,25 +103,6 @@ murano_opts = [
     cfg.StrOpt('url', help='Optional murano url in format '
                            'like http://0.0.0.0:8082 used by Murano engine'),
 
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                     '"insecure" SSL connections and transfers used by '
-                     'Murano engine.'),
-
-    cfg.StrOpt('cacert',
-               help='(SSL) Tells Murano to use the specified client '
-               'certificate file when communicating with Murano API '
-               'used by Murano engine.'),
-
-    cfg.StrOpt('cert_file',
-               help='(SSL) Tells Murano to use the specified client '
-                    'certificate file when communicating with Murano '
-                    'used by Murano engine.'),
-
-    cfg.StrOpt('key_file', help='(SSL/SSH) Private key file name '
-                                'to communicate with Murano API used by '
-                                'Murano engine.'),
-
     cfg.StrOpt('endpoint_type', default='publicURL',
                help='Murano endpoint type used by Murano engine.'),
 
@@ -169,6 +127,10 @@ murano_opts = [
     cfg.IntOpt('api_workers',
                help=_('Number of API workers')),
 
+    cfg.IntOpt('dsl_iterators_limit', default=2000,
+               help=_('Maximum number of elements that can be iterated per '
+                      'object type.')),
+
 ]
 
 networking_opts = [
@@ -179,9 +141,9 @@ networking_opts = [
     cfg.IntOpt('max_hosts', default=250,
                help='Maximum number of VMs per environment'),
 
-    cfg.StrOpt('env_ip_template', default='10.0.0.0',
-               help='Template IP address for generating environment '
-               'subnet cidrs'),
+    cfg.HostAddressOpt('env_ip_template', default='10.0.0.0',
+                       help='Template IP address for generating environment '
+                            'subnet cidrs'),
 
     cfg.ListOpt('default_dns', default=[],
                 help='List of default DNS nameservers to be assigned to '
@@ -266,25 +228,6 @@ glare_opts = [
                            'like http://0.0.0.0:9494 used by Glare API',
                deprecated_group='glance'),
 
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                '"insecure" SSL connections and transfers with Glare API.',
-                deprecated_group='glance'),
-
-    cfg.StrOpt('ca_file',
-               help='(SSL) Tells Murano to use the specified certificate file '
-               'to verify the peer running Glare API.',
-               deprecated_group='glance'),
-
-    cfg.StrOpt('cert_file',
-               help='(SSL) Tells Murano to use the specified client '
-               'certificate file when communicating with Glare.',
-               deprecated_group='glance'),
-
-    cfg.StrOpt('key_file', help='(SSL/SSH) Private key file name to '
-                                'communicate with Glare API.',
-               deprecated_group='glance'),
-
     cfg.StrOpt('endpoint_type', default='publicURL',
                help='Glare endpoint type.',
                deprecated_group='glance')
@@ -293,21 +236,6 @@ glare_opts = [
 glance_opts = [
     cfg.StrOpt('url', help='Optional glance endpoint override'),
 
-    cfg.BoolOpt('insecure', default=False,
-                help='This option explicitly allows Murano to perform '
-                '"insecure" SSL connections and transfers with Glance API.'),
-
-    cfg.StrOpt('ca_file',
-               help='(SSL) Tells Murano to use the specified certificate file '
-                    'to verify the peer running Glance API.'),
-
-    cfg.StrOpt('cert_file',
-               help='(SSL) Tells Murano to use the specified client '
-                    'certificate file when communicating with Glance.'),
-
-    cfg.StrOpt('key_file', help='(SSL/SSH) Private key file name to '
-                                'communicate with Glance API.'),
-
     cfg.StrOpt('endpoint_type', default='publicURL',
                help='Glance endpoint type.')
 ]
@@ -321,6 +249,12 @@ home_region = cfg.StrOpt(
     'home_region',
     help="Default region name used to get services endpoints.")
 
+# Unfortuntely we cannot use murano_auth.auth_url, since it
+# is private to the actual authentication plugin used.
+murano_auth_opts = [
+    cfg.StrOpt('auth_uri',
+               help='Identity API endpoint for authenticating with tokens.')]
+
 
 CONF = cfg.CONF
 CONF.register_opts(paste_deploy_opts, group='paste_deploy')
@@ -338,6 +272,22 @@ CONF.register_opts(stats_opts, group='stats')
 CONF.register_opts(networking_opts, group='networking')
 CONF.register_opts(glare_opts, group='glare')
 CONF.register_opts(glance_opts, group='glance')
+CONF.register_opts(murano_auth_opts, group='murano_auth')
+ks_loading.register_auth_conf_options(CONF, group='murano_auth')
+
+
+for group in ('heat', 'mistral', 'neutron', 'glance', 'glare',
+              'murano', 'murano_auth'):
+    ks_loading.register_session_conf_options(
+        CONF,
+        group=group,
+        deprecated_opts={
+            'cafile':   [cfg.DeprecatedOpt('cacert', group),
+                         cfg.DeprecatedOpt('ca_file', group)],
+            'certfile': [cfg.DeprecatedOpt('cert_file', group)],
+            'keyfile':  [cfg.DeprecatedOpt('key_file', group)]
+
+        })
 
 
 def parse_args(args=None, usage=None, default_config_files=None):
@@ -351,24 +301,23 @@ def parse_args(args=None, usage=None, default_config_files=None):
 
 def set_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
-    # CORS Defaults
-    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
-    cfg.set_defaults(cors.CORS_OPTS,
-                     allow_headers=['X-Auth-Token',
-                                    'X-Openstack-Request-Id',
-                                    'X-Configuration-Session',
-                                    'X-Roles',
-                                    'X-User-Id',
-                                    'X-Tenant-Id'],
-                     expose_headers=['X-Auth-Token',
-                                     'X-Openstack-Request-Id',
-                                     'X-Configuration-Session',
-                                     'X-Roles',
-                                     'X-User-Id',
-                                     'X-Tenant-Id'],
-                     allow_methods=['GET',
-                                    'PUT',
-                                    'POST',
-                                    'DELETE',
-                                    'PATCH']
-                     )
+
+    cors.set_defaults(
+        allow_headers=['X-Auth-Token',
+                       'X-Openstack-Request-Id',
+                       'X-Configuration-Session',
+                       'X-Roles',
+                       'X-User-Id',
+                       'X-Tenant-Id'],
+        expose_headers=['X-Auth-Token',
+                        'X-Openstack-Request-Id',
+                        'X-Configuration-Session',
+                        'X-Roles',
+                        'X-User-Id',
+                        'X-Tenant-Id'],
+        allow_methods=['GET',
+                       'PUT',
+                       'POST',
+                       'DELETE',
+                       'PATCH']
+    )
