@@ -15,8 +15,8 @@
 import os
 import shutil
 import sys
-import types
 
+import six
 import yaml
 
 from murano.packages import exceptions
@@ -32,7 +32,7 @@ class YAQL(object):
         self.expr = expr
 
 
-class Dumper(yaml.Dumper):
+class Dumper(yaml.SafeDumper):
     pass
 
 
@@ -44,10 +44,10 @@ Dumper.add_representer(YAQL, yaql_representer)
 
 
 class HotPackage(package_base.PackageBase):
-    def __init__(self, source_directory, manifest,
-                 package_format, runtime_version):
+    def __init__(self, format_name, runtime_version, source_directory,
+                 manifest):
         super(HotPackage, self).__init__(
-            source_directory, manifest, package_format, runtime_version)
+            format_name, runtime_version, source_directory, manifest)
 
         self._translated_class = None
         self._source_directory = source_directory
@@ -77,11 +77,12 @@ class HotPackage(package_base.PackageBase):
 
     def _translate_class(self):
         template_file = os.path.join(self._source_directory, 'template.yaml')
-        shutil.copy(template_file, self.get_resource(self.full_name))
 
         if not os.path.isfile(template_file):
             raise exceptions.PackageClassLoadError(
                 self.full_name, 'File with class definition not found')
+
+        shutil.copy(template_file, self.get_resource(self.full_name))
         with open(template_file) as stream:
             hot = yaml.safe_load(stream)
             if 'resources' not in hot:
@@ -107,7 +108,12 @@ class HotPackage(package_base.PackageBase):
 
         files = HotPackage._translate_files(self._source_directory)
         translated.update(HotPackage._generate_workflow(hot, files))
-        self._translated_class = yaml.dump(translated, Dumper=Dumper)
+
+        # use default_style with double quote mark because by default PyYAML
+        # doesn't put any quote marks ans as a result strings with e.g. dashes
+        # may be interpreted as YAQL expressions upon load
+        self._translated_class = yaml.dump(
+            translated, Dumper=Dumper, default_style='"')
 
     @staticmethod
     def _build_properties(hot, validate_hot_parameters):
@@ -172,7 +178,7 @@ class HotPackage(package_base.PackageBase):
     @staticmethod
     def _translate_outputs(hot):
         contract = {}
-        for key in (hot.get('outputs') or {}).iterkeys():
+        for key in (hot.get('outputs') or {}).keys():
             contract[key] = YAQL("$.string()")
         return {
             'templateOutputs': {
@@ -247,7 +253,7 @@ class HotPackage(package_base.PackageBase):
 
     @staticmethod
     def _format_value(value):
-        if isinstance(value, types.StringTypes):
+        if isinstance(value, six.string_types):
             return str("'" + value + "'")
         return str(value)
 
@@ -276,7 +282,7 @@ class HotPackage(package_base.PackageBase):
                 ]
             },
             {YAQL('$stack'): YAQL(
-                "new('io.murano.system.HeatStack', "
+                "new('io.murano.system.HeatStack', $environment, "
                 "name => $.getAttr(generatedHeatStackName))")},
 
             YAQL("$reporter.report($this, "
@@ -326,10 +332,12 @@ class HotPackage(package_base.PackageBase):
         ]
 
         destroy = [
+            {YAQL('$environment'): YAQL(
+                "$.find('io.murano.Environment').require()"
+            )},
             {YAQL('$stack'): YAQL(
-                "new('io.murano.system.HeatStack', "
+                "new('io.murano.system.HeatStack', $environment, "
                 "name => $.getAttr(generatedHeatStackName))")},
-
             YAQL('$stack.delete()')
         ]
 
@@ -383,7 +391,7 @@ class HotPackage(package_base.PackageBase):
 
         rest_group = []
         properties = []
-        for key, value in hot_parameters.iteritems():
+        for key, value in hot_parameters.items():
             if key not in used_parameters:
                 rest_group.append(HotPackage._translate_ui_parameter(
                     key, value))
@@ -432,11 +440,11 @@ class HotPackage(package_base.PackageBase):
                 spec = constraint['length']
                 if 'min' in spec:
                     translated['minLength'] = max(
-                        translated.get('minLength', -sys.maxint - 1),
+                        translated.get('minLength', -sys.maxsize - 1),
                         int(spec['min']))
                 if 'max' in spec:
                     translated['maxLength'] = min(
-                        translated.get('maxLength', sys.maxint),
+                        translated.get('maxLength', sys.maxsize),
                         int(spec['max']))
 
             elif 'range' in constraint:
@@ -485,12 +493,17 @@ class HotPackage(package_base.PackageBase):
         return translated
 
     @staticmethod
-    def _generate_application_ui(groups, type_name):
+    def _generate_application_ui(groups, type_name,
+                                 package_name=None, package_version=None):
         app = {
             '?': {
                 'type': type_name
             }
         }
+        if package_name:
+            app['?']['package'] = package_name
+        if package_version:
+            app['?']['classVersion'] = package_version
         for i, record in enumerate(groups):
             if i == 0:
                 section = app
@@ -520,7 +533,9 @@ class HotPackage(package_base.PackageBase):
         translated = {
             'Version': 2,
             'Application': HotPackage._generate_application_ui(
-                groups, self.full_name),
+                groups, self.full_name, self.full_name, str(self.version)),
             'Forms': forms
         }
-        return yaml.dump(translated, Dumper=Dumper)
+
+        # see comment above about default_style
+        return yaml.dump(translated, Dumper=Dumper, default_style='"')
