@@ -16,6 +16,7 @@ import os
 import testtools
 
 from tempest import config
+from tempest.lib import decorators
 
 from murano_tempest_tests.tests.scenario.application_catalog import base
 from murano_tempest_tests import utils
@@ -25,10 +26,34 @@ CONF = config.CONF
 
 class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
 
+    @classmethod
+    def skip_checks(cls):
+        super(TestCinderVolumes, cls).skip_checks()
+        if not CONF.service_available.cinder:
+            msg = "Cinder is not available. Skipping volumes tests"
+            raise cls.skipException(msg)
+        if (not CONF.volume_feature_enabled.api_v3 and
+                not CONF.volume_feature_enabled.api_v2):
+            msg = ("Neither cinder v2 nor v3 are available. Skipping"
+                   "volumes tests")
+            raise cls.skipException(msg)
+
+    @classmethod
+    def setup_clients(cls):
+        super(TestCinderVolumes, cls).setup_clients()
+        # Prefer volume v3 which is the current version
+        if CONF.volume_feature_enabled.api_v3:
+            _volume = cls.services_manager.volume_v3
+        elif CONF.volume_feature_enabled.api_v2:
+            _volume = cls.services_manager.volume_v2
+        cls.volumes_client = _volume.VolumesClient()
+        cls.backups_client = _volume.BackupsClient()
+        cls.snapshots_client = _volume.SnapshotsClient()
+
     @classmethod
     def resource_setup(cls):
         if not CONF.application_catalog.cinder_volume_tests:
-            msg = "Cinder volumes attachment tests will be skipped."
+            msg = "Cinder volumes tests will be skipped."
             raise cls.skipException(msg)
         super(TestCinderVolumes, cls).resource_setup()
         cls.linux = CONF.application_catalog.linux_image
@@ -49,11 +74,12 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
 
     @classmethod
     def resource_cleanup(cls):
-        cls.delete_volume(cls.volume)
+        cls.delete_volume(cls.volume['id'])
         cls.client.delete_package(cls.package['id'])
         os.remove(cls.abs_archive_path)
         super(TestCinderVolumes, cls).resource_cleanup()
 
+    @decorators.idempotent_id('241ace7d-3b6e-413e-8936-a851ff1163f8')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_boot_volume_as_image(self):
@@ -78,7 +104,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
             create_session(environment['id'])
         post_body = {
             "instance": {
-                "flavor": "m1.small",
+                "flavor": "m1.tiny",
                 "blockDevices": {
                     "volume": {
                         "?": {
@@ -122,6 +148,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
         self.assertFalse(
             self.servers_client.show_server(server)['server']['image'])
 
+    @decorators.idempotent_id('e10d3bad-7145-46df-8118-4040842883f6')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_existing_volume(self):
@@ -148,7 +175,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
                 "?": {
                     "type": "io.murano.resources.ExistingCinderVolume"
                 },
-                "openstackId": self.volume
+                "openstackId": self.volume['id']
             }
         }
         post_body = self.vm_cinder(attributes=volume_attributes)
@@ -157,8 +184,9 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
                            post_body)
         self.deploy_environment(environment, session)
 
-        self.check_volume_attached('testMurano', self.volume)
+        self.check_volume_attached('testMurano', self.volume['id'])
 
+    @decorators.idempotent_id('6338a496-7415-42a9-a514-61f6f5cb1e65')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_volume_creation(self):
@@ -172,7 +200,8 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
             4. Make sure that deployment finished successfully
             5. Check that application is accessible
             6. Check that volume is attached to the instance and has size 1GiB
-            7. Delete environment
+            7. Check that we can access some attachment info about the volume
+            8. Delete environment
         """
         name = utils.generate_name('testMurano')
         environment = self.application_catalog_client.\
@@ -196,8 +225,10 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
 
         volume_data = self.get_volume(environment['id'])
         self.check_volume_attached('testMurano', volume_data['id'])
+        self.check_volume_attachments(environment['id'])
         self.assertEqual(volume_data['size'], 1)
 
+    @decorators.idempotent_id('1eb9bbe4-9810-408e-86a0-78ff114aadae')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_volume_creation_from_image(self):
@@ -241,6 +272,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
         self.assertEqual(volume_data['volume_image_metadata']['image_name'],
                          self.cirros_image)
 
+    @decorators.idempotent_id('bd624a9b-10ae-4079-b515-7b6031d9e725')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_volume_creation_from_volume(self):
@@ -274,7 +306,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
                     "?": {
                         "type": "io.murano.resources.ExistingCinderVolume"
                     },
-                    "openstackId": self.volume
+                    "openstackId": self.volume['id']
                 }
             }
         }
@@ -287,8 +319,9 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
         volume_data = self.get_volume(environment['id'])
         self.check_volume_attached('testMurano', volume_data['id'])
         self.assertEqual(volume_data['size'], 1)
-        self.assertEqual(volume_data['source_volid'], self.volume)
+        self.assertEqual(volume_data['source_volid'], self.volume['id'])
 
+    @decorators.idempotent_id('7a671222-160d-4594-97bf-ea47f60ad965')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_volume_creation_from_snapshot(self):
@@ -307,8 +340,8 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
             created from existing volume snapshot
             8. Delete environment, snapshot
         """
-        snapshot = self.create_snapshot(self.volume)
-        self.addCleanup(self.delete_snapshot, snapshot)
+        snapshot = self.create_snapshot(self.volume['id'])
+        self.addCleanup(self.delete_snapshot, snapshot['id'])
         name = utils.generate_name('testMurano')
         environment = self.application_catalog_client.\
             create_environment(name)
@@ -325,7 +358,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
                     "?": {
                         "type": "io.murano.resources.CinderVolumeSnapshot"
                     },
-                    "openstackId": snapshot
+                    "openstackId": snapshot['id']
                 }
             }
         }
@@ -338,7 +371,7 @@ class TestCinderVolumes(base.BaseApplicationCatalogScenarioTest):
         volume_data = self.get_volume(environment['id'])
         self.check_volume_attached('testMurano', volume_data['id'])
         self.assertEqual(volume_data['size'], 1)
-        self.assertEqual(volume_data['snapshot_id'], snapshot)
+        self.assertEqual(volume_data['snapshot_id'], snapshot['id'])
 
 
 class TestCinderVolumeIsolatedAdmin(
@@ -367,26 +400,27 @@ class TestCinderVolumeIsolatedAdmin(
 
     @classmethod
     def resource_cleanup(cls):
-        cls.delete_volume(cls.volume)
+        cls.delete_volume(cls.volume['id'])
         cls.client.delete_package(cls.package['id'])
         os.remove(cls.abs_archive_path)
         super(TestCinderVolumeIsolatedAdmin, cls).resource_cleanup()
 
+    @decorators.idempotent_id('4111eb94-2636-4d0b-af5c-776ed5a59b87')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
-    def test_deploy_app_with_volume_creation_readonly_multiattach(self):
-        """Test app deploy with volume creation with multiattach and readonly
+    def test_deploy_app_with_volume_creation_readonly(self):
+        """Test app deploy with volume creation with readonly
 
         Scenario:
             1. Create environment
             2. Add VM application with ability to create and
-            attach Cinder volume with size 1 GiB, multiattach and readonly
+            attach Cinder volume with size 1 GiB and readonly
             properties to the instance
             3. Deploy environment
             4. Make sure that deployment finished successfully
             5. Check that application is accessible
             6. Check that volume is attached to the instance, has size 1GiB,
-            multiattach, readonly attributes
+            and readonly attributes
             7. Delete environment
         """
         name = utils.generate_name('testMurano')
@@ -401,8 +435,7 @@ class TestCinderVolumeIsolatedAdmin(
                     "type": "io.murano.resources.CinderVolume"
                 },
                 "size": 1,
-                "readOnly": True,
-                "multiattach": True
+                "readOnly": True
             }
         }
         post_body = self.vm_cinder(attributes=volume_attributes)
@@ -415,8 +448,8 @@ class TestCinderVolumeIsolatedAdmin(
         self.check_volume_attached('testMurano', volume_data['id'])
         self.assertEqual(volume_data['size'], 1)
         self.assertEqual(volume_data['metadata']['readonly'], 'True')
-        self.assertTrue(volume_data['multiattach'])
 
+    @decorators.idempotent_id('5c134343-11bc-4329-ac30-9b43f32c15e2')
     @testtools.testcase.attr('smoke')
     @testtools.testcase.attr('scenario')
     def test_deploy_app_with_volume_creation_from_backup(self):
@@ -442,8 +475,8 @@ class TestCinderVolumeIsolatedAdmin(
                    "will be skipped.")
             raise self.skipException(msg)
 
-        backup = self.create_backup(self.volume)
-        self.addCleanup(self.delete_backup, backup)
+        backup = self.create_backup(self.volume['id'])
+        self.addCleanup(self.delete_backup, backup['id'])
         name = utils.generate_name('testMurano')
         environment = self.application_catalog_client. \
             create_environment(name)
@@ -456,12 +489,12 @@ class TestCinderVolumeIsolatedAdmin(
                     "type": "io.murano.resources.CinderVolume"
                 },
                 "size": 1,
-                "name": "restore_backup_" + backup,
+                "name": "restore_backup_" + backup['id'],
                 "sourceVolumeBackup": {
                     "?": {
                         "type": "io.murano.resources.CinderVolumeBackup"
                     },
-                    "openstackId": backup
+                    "openstackId": backup['id']
                 }
             }
         }
@@ -474,4 +507,4 @@ class TestCinderVolumeIsolatedAdmin(
         volume_data = self.get_volume(environment['id'])
         self.check_volume_attached('testMurano', volume_data['id'])
         self.assertEqual(volume_data['size'], 1)
-        self.assertIn(backup, volume_data['name'])
+        self.assertIn(backup['id'], volume_data['name'])
